@@ -1,16 +1,16 @@
-/* base32.h
+/** @file
  * Base-32 conversion
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef __BASE32_H__
 #define __BASE32_H__
 
-#include "ws_symbol_export.h"
+#include <wireshark.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -23,8 +23,8 @@ extern "C" {
 
 /* Encoding of a base32 byte array */
 WS_DLL_PUBLIC
-int ws_base32_decode(guint8* output, const guint32 outputLength,
-						const guint8* in, const guint32 inputLength);
+int ws_base32_decode(uint8_t* output, const uint32_t outputLength,
+						const uint8_t* in, const uint32_t inputLength);
 
 #ifdef __cplusplus
 }
